@@ -190,7 +190,7 @@ def aria2c_downloader(
             File file = glob("__out/*")[0]
         }
         runtime {
-            cpu: 4
+            cpu: 2
             memory: "1G"
             docker: docker
         }
@@ -223,6 +223,8 @@ def awscli_downloader(
                 if [ -n "~{aws_credentials}" ]; then
                     source "~{aws_credentials}"
                 fi
+                export AWS_RETRY_MODE=standard
+                export AWS_MAX_ATTEMPTS=5
                 set -x
                 mkdir __out
                 if ! aws s3 cp "~{uri}" __out/ ; then
@@ -231,6 +233,8 @@ def awscli_downloader(
                     # credentials are available or (ii) the IAM policy restricts accessible S3
                     # buckets regardless of whether the desired object is public.
                     rm -f __out/*
+                    >&2 echo 'Retrying with --no-sign-request in case the object is public.' \
+                         ' If the overall operation fails, the real error may precede this message.'
                     aws s3 cp --no-sign-request "~{uri}" __out/
                 fi
             >>>
@@ -240,7 +244,7 @@ def awscli_downloader(
             }
 
             runtime {
-                cpu: 4
+                cpu: 2
                 memory: "1G"
                 docker: docker
             }
@@ -272,6 +276,8 @@ def awscli_directory_downloader(
                 if [ -n "~{aws_credentials}" ]; then
                     source "~{aws_credentials}"
                 fi
+                export AWS_RETRY_MODE=standard
+                export AWS_MAX_ATTEMPTS=5
                 set -x
                 mkdir -p "__out/~{dnm}/"
                 if ! aws s3 cp --recursive "~{uri}" "__out/~{dnm}/" ; then
@@ -280,6 +286,8 @@ def awscli_directory_downloader(
                     # credentials are available or (ii) the IAM policy restricts accessible S3
                     # buckets regardless of whether the desired object is public.
                     rm -f "__out/~{dnm}/*"
+                    >&2 echo 'Retrying with --no-sign-request in case the folder is public.' \
+                        ' If the overall operation fails, the real error may precede this message.'
                     aws s3 cp --recursive --no-sign-request "~{uri}" "__out/~{dnm}/"
                 fi
             >>>
@@ -289,7 +297,7 @@ def awscli_directory_downloader(
             }
 
             runtime {
-                cpu: 4
+                cpu: 2
                 memory: "1G"
                 docker: docker
             }
@@ -308,9 +316,9 @@ def prepare_aws_credentials(
         host_aws_credentials["AWS_EC2_METADATA_DISABLED"] = os.environ["AWS_EC2_METADATA_DISABLED"]
     # get AWS credentials from boto3 (unless prevented by configuration)
     if cfg["download_awscli"].get_bool("host_credentials"):
-        try:
-            import boto3  # pyre-fixme
+        import boto3  # pyre-fixme
 
+        try:
             b3creds = boto3.session.Session().get_credentials()
             host_aws_credentials["AWS_ACCESS_KEY_ID"] = b3creds.access_key
             host_aws_credentials["AWS_SECRET_ACCESS_KEY"] = b3creds.secret_key
@@ -372,7 +380,7 @@ def gsutil_downloader(
             File file = glob("__out/*")[0]
         }
         runtime {
-            cpu: 4
+            cpu: 2
             memory: "1G"
             docker: docker
         }
